# Autoexplain

Autoexplain is an open source tool that allows you to create documents automatically.

## How to use it?
You can use it directly in your terminal. To get a view of the possible commands, use:
```autoexplain -h```

## How does it work?
It uses OpenAI to generate documentation automatically. That means you will need
[an OpenAI key](https://beta.openai.com/) to use this tool - create an account if you 
don't have it, click above right in your profile and in 'View API keys'. 

To init tool, execute the following in your terminal:

```autoexplain set-key [OPENAI_KEY]```

## Why use it?
It's an alternative to the traditional way of documenting your code, where you
write down the documentation in a text file.

Also, because documenting is quite boring.

## How to install?
With pip:

```pip install autoexplain```

## How to contribute?
This project is completely open source. You can report bugs, make requests and send 
patches through the Github repository.

## How to contact the authors?
You can contact the authors in the following ways:

- Email: rincon.santi@gmail.com
- LinkedIn: https://www.linkedin.com/in/santiago-rincon-martinez/

## What license is it distributed under?
This project is distributed under the GNU GENERAL PUBLIC LICENSE license. Read the 
full text of the license in the file [LICENSE].

## Special thanks
Prompt generation for readme has been brought from [https://github.com/tom-doerr/codex-readme] 
(MIT Licensed)